ZeytinChapterModel class

Constructors

ZeytinChapterModel({required String id, required String bookId, required String title, String? description, required String content, required int order, DateTime? publishedDate, Map<String, dynamic>? moreData})
ZeytinChapterModel.empty()
factory
ZeytinChapterModel.fromJson(Map<String, dynamic> data)
factory

Properties

bookId String
final
content String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
moreData Map<String, dynamic>?
final
order int
final
publishedDate DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

copyWith({String? id, String? bookId, String? title, String? description, String? content, int? order, DateTime? publishedDate, Map<String, dynamic>? moreData}) ZeytinChapterModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited